@@ -24,6 +24,7 @@ from .paginator import (
     ListAccountAssignmentDeletionStatusPaginator,
     ListAccountAssignmentsPaginator,
     ListAccountsForProvisionedPermissionSetPaginator,
+    ListCustomerManagedPolicyReferencesInPermissionSetPaginator,
     ListInstancesPaginator,
     ListManagedPoliciesInPermissionSetPaginator,
     ListPermissionSetProvisioningStatusPaginator,
@@ -34,6 +35,7 @@ from .paginator import (
 from .type_defs import (
     CreateAccountAssignmentResponseTypeDef,
     CreatePermissionSetResponseTypeDef,
+    CustomerManagedPolicyReferenceTypeDef,
     DeleteAccountAssignmentResponseTypeDef,
     DescribeAccountAssignmentCreationStatusResponseTypeDef,
     DescribeAccountAssignmentDeletionStatusResponseTypeDef,
@@ -41,11 +43,13 @@ from .type_defs import (
     DescribePermissionSetProvisioningStatusResponseTypeDef,
     DescribePermissionSetResponseTypeDef,
     GetInlinePolicyForPermissionSetResponseTypeDef,
+    GetPermissionsBoundaryForPermissionSetResponseTypeDef,
     InstanceAccessControlAttributeConfigurationTypeDef,
     ListAccountAssignmentCreationStatusResponseTypeDef,
     ListAccountAssignmentDeletionStatusResponseTypeDef,
     ListAccountAssignmentsResponseTypeDef,
     ListAccountsForProvisionedPermissionSetResponseTypeDef,
+    ListCustomerManagedPolicyReferencesInPermissionSetResponseTypeDef,
     ListInstancesResponseTypeDef,
     ListManagedPoliciesInPermissionSetResponseTypeDef,
     ListPermissionSetProvisioningStatusResponseTypeDef,
@@ -53,6 +57,7 @@ from .type_defs import (
     ListPermissionSetsResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
     OperationStatusFilterTypeDef,
+    PermissionsBoundaryTypeDef,
     ProvisionPermissionSetResponseTypeDef,
     TagTypeDef,
 )
@@ -102,11 +107,26 @@ class SSOAdminClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#exceptions)
         """
 
+    def attach_customer_managed_policy_reference_to_permission_set(
+        self,
+        *,
+        InstanceArn: str,
+        PermissionSetArn: str,
+        CustomerManagedPolicyReference: CustomerManagedPolicyReferenceTypeDef
+    ) -> Dict[str, Any]:
+        """
+        Attaches the specified IAM customer managed policy to the specified
+        PermissionSet .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.attach_customer_managed_policy_reference_to_permission_set)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#attach_customer_managed_policy_reference_to_permission_set)
+        """
+
     def attach_managed_policy_to_permission_set(
         self, *, InstanceArn: str, PermissionSetArn: str, ManagedPolicyArn: str
     ) -> Dict[str, Any]:
         """
-        Attaches an IAM managed policy ARN to a permission set.
+        Attaches an Amazon Web Services managed IAM policy ARN to a permission set.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.attach_managed_policy_to_permission_set)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#attach_managed_policy_to_permission_set)
@@ -120,6 +140,14 @@ class SSOAdminClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#close)
+        """
+
     def create_account_assignment(
         self,
         *,
@@ -142,7 +170,7 @@ class SSOAdminClient(BaseClient):
         self,
         *,
         InstanceArn: str,
-        InstanceAccessControlAttributeConfiguration: "InstanceAccessControlAttributeConfigurationTypeDef"
+        InstanceAccessControlAttributeConfiguration: InstanceAccessControlAttributeConfigurationTypeDef
     ) -> Dict[str, Any]:
         """
         Enables the attributes-based access control (ABAC) feature for the specified
@@ -160,7 +188,7 @@ class SSOAdminClient(BaseClient):
         Description: str = ...,
         SessionDuration: str = ...,
         RelayState: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreatePermissionSetResponseTypeDef:
         """
         Creates a permission set within a specified SSO instance.
@@ -217,6 +245,16 @@ class SSOAdminClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#delete_permission_set)
         """
 
+    def delete_permissions_boundary_from_permission_set(
+        self, *, InstanceArn: str, PermissionSetArn: str
+    ) -> Dict[str, Any]:
+        """
+        Deletes the permissions boundary from a specified  PermissionSet .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.delete_permissions_boundary_from_permission_set)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#delete_permissions_boundary_from_permission_set)
+        """
+
     def describe_account_assignment_creation_status(
         self, *, InstanceArn: str, AccountAssignmentCreationRequestId: str
     ) -> DescribeAccountAssignmentCreationStatusResponseTypeDef:
@@ -269,11 +307,27 @@ class SSOAdminClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#describe_permission_set_provisioning_status)
         """
 
+    def detach_customer_managed_policy_reference_from_permission_set(
+        self,
+        *,
+        InstanceArn: str,
+        PermissionSetArn: str,
+        CustomerManagedPolicyReference: CustomerManagedPolicyReferenceTypeDef
+    ) -> Dict[str, Any]:
+        """
+        Detaches the specified IAM customer managed policy from the specified
+        PermissionSet .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.detach_customer_managed_policy_reference_from_permission_set)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#detach_customer_managed_policy_reference_from_permission_set)
+        """
+
     def detach_managed_policy_from_permission_set(
         self, *, InstanceArn: str, PermissionSetArn: str, ManagedPolicyArn: str
     ) -> Dict[str, Any]:
         """
-        Detaches the attached IAM managed policy ARN from the specified permission set.
+        Detaches the attached Amazon Web Services managed IAM policy ARN from the
+        specified permission set.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.detach_managed_policy_from_permission_set)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#detach_managed_policy_from_permission_set)
@@ -303,13 +357,23 @@ class SSOAdminClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_inline_policy_for_permission_set)
         """
 
+    def get_permissions_boundary_for_permission_set(
+        self, *, InstanceArn: str, PermissionSetArn: str
+    ) -> GetPermissionsBoundaryForPermissionSetResponseTypeDef:
+        """
+        Obtains the permissions boundary for a specified  PermissionSet .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.get_permissions_boundary_for_permission_set)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_permissions_boundary_for_permission_set)
+        """
+
     def list_account_assignment_creation_status(
         self,
         *,
         InstanceArn: str,
         MaxResults: int = ...,
         NextToken: str = ...,
-        Filter: "OperationStatusFilterTypeDef" = ...
+        Filter: OperationStatusFilterTypeDef = ...
     ) -> ListAccountAssignmentCreationStatusResponseTypeDef:
         """
         Lists the status of the Amazon Web Services account assignment creation requests
@@ -325,7 +389,7 @@ class SSOAdminClient(BaseClient):
         InstanceArn: str,
         MaxResults: int = ...,
         NextToken: str = ...,
-        Filter: "OperationStatusFilterTypeDef" = ...
+        Filter: OperationStatusFilterTypeDef = ...
     ) -> ListAccountAssignmentDeletionStatusResponseTypeDef:
         """
         Lists the status of the Amazon Web Services account assignment deletion requests
@@ -369,6 +433,21 @@ class SSOAdminClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_accounts_for_provisioned_permission_set)
         """
 
+    def list_customer_managed_policy_references_in_permission_set(
+        self,
+        *,
+        InstanceArn: str,
+        PermissionSetArn: str,
+        MaxResults: int = ...,
+        NextToken: str = ...
+    ) -> ListCustomerManagedPolicyReferencesInPermissionSetResponseTypeDef:
+        """
+        Lists all IAM customer managed policies attached to a specified  PermissionSet .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_customer_managed_policy_references_in_permission_set)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_customer_managed_policy_references_in_permission_set)
+        """
+
     def list_instances(
         self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListInstancesResponseTypeDef:
@@ -388,7 +467,8 @@ class SSOAdminClient(BaseClient):
         NextToken: str = ...
     ) -> ListManagedPoliciesInPermissionSetResponseTypeDef:
         """
-        Lists the IAM managed policy that is attached to a specified permission set.
+        Lists the Amazon Web Services managed IAM policy that is attached to a specified
+        permission set.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_managed_policies_in_permission_set)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_managed_policies_in_permission_set)
@@ -400,7 +480,7 @@ class SSOAdminClient(BaseClient):
         InstanceArn: str,
         MaxResults: int = ...,
         NextToken: str = ...,
-        Filter: "OperationStatusFilterTypeDef" = ...
+        Filter: OperationStatusFilterTypeDef = ...
     ) -> ListPermissionSetProvisioningStatusResponseTypeDef:
         """
         Lists the status of the permission set provisioning requests for a specified SSO
@@ -473,8 +553,23 @@ class SSOAdminClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#put_inline_policy_to_permission_set)
         """
 
+    def put_permissions_boundary_to_permission_set(
+        self,
+        *,
+        InstanceArn: str,
+        PermissionSetArn: str,
+        PermissionsBoundary: PermissionsBoundaryTypeDef
+    ) -> Dict[str, Any]:
+        """
+        Attaches an Amazon Web Services managed or customer managed IAM policy to the
+        specified  PermissionSet as a permissions boundary.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.put_permissions_boundary_to_permission_set)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#put_permissions_boundary_to_permission_set)
+        """
+
     def tag_resource(
-        self, *, InstanceArn: str, ResourceArn: str, Tags: Sequence["TagTypeDef"]
+        self, *, InstanceArn: str, ResourceArn: str, Tags: Sequence[TagTypeDef]
     ) -> Dict[str, Any]:
         """
         Associates a set of tags with a specified resource.
@@ -497,7 +592,7 @@ class SSOAdminClient(BaseClient):
         self,
         *,
         InstanceArn: str,
-        InstanceAccessControlAttributeConfiguration: "InstanceAccessControlAttributeConfigurationTypeDef"
+        InstanceAccessControlAttributeConfiguration: InstanceAccessControlAttributeConfigurationTypeDef
     ) -> Dict[str, Any]:
         """
         Updates the Amazon Web Services SSO identity store attributes that you can use
@@ -560,6 +655,15 @@ class SSOAdminClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_paginator)
         """
 
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["list_customer_managed_policy_references_in_permission_set"]
+    ) -> ListCustomerManagedPolicyReferencesInPermissionSetPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_paginator)
+        """
+
     @overload
     def get_paginator(self, operation_name: Literal["list_instances"]) -> ListInstancesPaginator:
         """
