@@ -25,6 +25,7 @@ __all__ = (
     "ListAccountAssignmentDeletionStatusPaginatorName",
     "ListAccountAssignmentsPaginatorName",
     "ListAccountsForProvisionedPermissionSetPaginatorName",
+    "ListCustomerManagedPolicyReferencesInPermissionSetPaginatorName",
     "ListInstancesPaginatorName",
     "ListManagedPoliciesInPermissionSetPaginatorName",
     "ListPermissionSetProvisioningStatusPaginatorName",
@@ -40,6 +41,7 @@ __all__ = (
     "ServiceName",
     "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -56,6 +58,9 @@ ListAccountAssignmentsPaginatorName = Literal["list_account_assignments"]
 ListAccountsForProvisionedPermissionSetPaginatorName = Literal[
     "list_accounts_for_provisioned_permission_set"
 ]
+ListCustomerManagedPolicyReferencesInPermissionSetPaginatorName = Literal[
+    "list_customer_managed_policy_references_in_permission_set"
+]
 ListInstancesPaginatorName = Literal["list_instances"]
 ListManagedPoliciesInPermissionSetPaginatorName = Literal["list_managed_policies_in_permission_set"]
 ListPermissionSetProvisioningStatusPaginatorName = Literal[
@@ -144,6 +149,7 @@ ServiceName = Literal[
     "config",
     "connect",
     "connect-contact-lens",
+    "connectcampaigns",
     "connectparticipant",
     "cur",
     "customer-profiles",
@@ -180,6 +186,7 @@ ServiceName = Literal[
     "elbv2",
     "emr",
     "emr-containers",
+    "emr-serverless",
     "es",
     "events",
     "evidently",
@@ -253,6 +260,7 @@ ServiceName = Literal[
     "lookoutequipment",
     "lookoutmetrics",
     "lookoutvision",
+    "m2",
     "machinelearning",
     "macie",
     "macie2",
@@ -309,11 +317,13 @@ ServiceName = Literal[
     "rds-data",
     "redshift",
     "redshift-data",
+    "redshift-serverless",
     "rekognition",
     "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
+    "rolesanywhere",
     "route53",
     "route53-recovery-cluster",
     "route53-recovery-control-config",
@@ -398,6 +408,7 @@ PaginatorName = Literal[
     "list_account_assignment_deletion_status",
     "list_account_assignments",
     "list_accounts_for_provisioned_permission_set",
+    "list_customer_managed_policy_references_in_permission_set",
     "list_instances",
     "list_managed_policies_in_permission_set",
     "list_permission_set_provisioning_status",
@@ -405,3 +416,24 @@ PaginatorName = Literal[
     "list_permission_sets_provisioned_to_account",
     "list_tags_for_resource",
 ]
+RegionName = Literal[
+    "ap-east-1",
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-northeast-3",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "ca-central-1",
+    "eu-central-1",
+    "eu-north-1",
+    "eu-south-1",
+    "eu-west-1",
+    "eu-west-2",
+    "eu-west-3",
+    "me-south-1",
+    "sa-east-1",
+    "us-east-1",
+    "us-east-2",
+    "us-west-2",
+]
